## cdist-type__iptables_apply(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__iptables_apply - Apply the rules

## 2. DESCRIPTION

This cdist type deploys an init script that triggers the configured rules and also re-applies them on configuration.

## 3. REQUIRED PARAMETERS

None

## 4. OPTIONAL PARAMETERS

None

## 5. EXAMPLES

None (iptables_apply is used by iptables_rule)

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__iptables_rule(7)
- iptables(8)

## 7. COPYING

Copyright (C) 2013 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).